import { Facet, StateEffect, StateField } from "@codemirror/state";
// Default keymap values
export const defaultKeymaps = {
    showInput: "Mod-l",
    acceptEdit: "Mod-y",
    rejectEdit: "Mod-u",
};
// Facet for options
export const optionsFacet = Facet.define({
    combine: (values) => Object.assign({}, ...values),
});
// State effect to show/hide the tooltip
export const showTooltip = StateEffect.define();
// State field to manage the tooltip visibility
export const tooltipState = StateField.define({
    create() {
        return false;
    },
    update(value, tr) {
        for (const e of tr.effects) {
            if (e.is(showTooltip)) {
                return e.value;
            }
        }
        return value;
    },
});
// State effect to show/hide the input
export const showInput = StateEffect.define();
// State field to manage the input visibility and position
export const inputState = StateField.define({
    create() {
        return { show: false, from: 0, to: 0 };
    },
    update(value, tr) {
        for (const e of tr.effects) {
            if (e.is(showInput)) {
                return e.value;
            }
        }
        return value;
    },
});
// State effect to show/hide the completion
export const showCompletion = StateEffect.define();
// State field to manage the completion
export const completionState = StateField.define({
    create() {
        return null;
    },
    update(value, tr) {
        for (const e of tr.effects) {
            if (e.is(showCompletion)) {
                return e.value;
            }
        }
        return value;
    },
});
// State effect and field for loading status
export const setLoading = StateEffect.define();
export const loadingState = StateField.define({
    create() {
        return false;
    },
    update(value, tr) {
        for (const e of tr.effects) {
            if (e.is(setLoading)) {
                return e.value;
            }
        }
        return value;
    },
});
//# sourceMappingURL=state.js.map